"use strict";

var _chunkMFR6AGTJcjs = require('../../chunk-MFR6AGTJ.cjs');
require('../../chunk-34HB56WE.cjs');
require('../../chunk-XTDX3HZA.cjs');
require('../../chunk-EST7HNFV.cjs');
require('../../chunk-RHWKNEUH.cjs');


var _chunkN5KTMDVOcjs = require('../../chunk-N5KTMDVO.cjs');
require('../../chunk-2AGPRCO5.cjs');
require('../../chunk-6R46PMWT.cjs');
require('../../chunk-6AARQEB3.cjs');
require('../../chunk-S4V3EGNS.cjs');
require('../../chunk-HHZVPIBD.cjs');
require('../../chunk-SX5YQHZO.cjs');
require('../../chunk-UKD65B23.cjs');
require('../../chunk-TZXDYORA.cjs');
require('../../chunk-J42M6DF3.cjs');
require('../../chunk-ZYPCVNSG.cjs');
require('../../chunk-VAG3XY63.cjs');
require('../../chunk-W3WUDQIC.cjs');
require('../../chunk-YY4AHBBL.cjs');
require('../../chunk-IMCDDJAJ.cjs');

// src/common/exec/queue.spec.ts
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new (0, _chunkMFR6AGTJcjs.SerialQueue)();
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    void (async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 100);
      list.push("a");
    })();
    void (async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 200);
      list.push("b");
    })();
    void (async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 1);
      list.push("c");
    })();
    await _chunkN5KTMDVOcjs.sleep.call(void 0, 500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new (0, _chunkMFR6AGTJcjs.SerialQueue)();
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkMFR6AGTJcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkMFR6AGTJcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkN5KTMDVOcjs.sleep.call(void 0, 1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.cjs.map