import "../chunk-EW6FHLFK.js";
import "../chunk-2VA3UGW7.js";
import "../chunk-XZC66A25.js";
import "../chunk-STE4YAST.js";
import "../chunk-TFZ4P4OR.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-OSX4VQOR.js";
import "../chunk-7QYVSWCZ.js";
import "../chunk-XWEP5CLU.js";
import "../chunk-UO7L7NBK.js";
import "../chunk-TRCJY7KG.js";
import {
  sleep
} from "../chunk-L324TYGN.js";
import "../chunk-K7Z2KDW3.js";
import "../chunk-GY34N3KU.js";
import "../chunk-QUKKMPRF.js";
import "../chunk-XYJV3SSU.js";
import "../chunk-JZBMDET5.js";
import "../chunk-BFL67QFN.js";
import "../chunk-RSLTBO5X.js";
import "../chunk-EJGW3W3K.js";
import {
  dateFromSeconds,
  datetimeToLocal,
  datetimeToUTC,
  duration,
  formatMilliseconds,
  getPerformanceTimestamp,
  getTimestamp,
  getTimestampInSeconds,
  parseDate
} from "../chunk-QV2QPYMW.js";
import "../chunk-MIZOLME5.js";
import "../chunk-AQUNU3KH.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-CFICINSP.js";
import "../chunk-V5ZQ2SFQ.js";
import "../chunk-UOAPXGA4.js";
import "../chunk-EAYWSLQT.js";
import "../chunk-I7BWSAN6.js";

// src/common/time.spec.ts
describe("time.spec", () => {
  it("should measure", async () => {
    const getDuration = duration();
    await sleep(50);
    const elapsed = getDuration();
    expect(/\d+.\d\d ms/.test(elapsed)).toBe(true);
  });
  it("should parse valid date strings", () => {
    const date1 = parseDate("2022-01-01");
    const date2 = parseDate("2022-01-01T12:00:00");
    expect(date1).toEqual(new Date(2022, 0, 1, 12, 0));
    expect(date2).toEqual(/* @__PURE__ */ new Date("2022-01-01T12:00:00"));
  });
  it("should return undefined for invalid date strings", () => {
    const date = parseDate("invalid-date");
    expect(date).toBeUndefined();
  });
  it("should return the input date if it is already a Date object", () => {
    const inputDate = /* @__PURE__ */ new Date();
    const date = parseDate(inputDate);
    expect(date).toBe(inputDate);
  });
  it("should convert dates", () => {
    const dateLocal = /* @__PURE__ */ new Date("2022-01-01T12:00:00");
    expect(datetimeToLocal(datetimeToUTC(dateLocal))).toEqual(dateLocal);
  });
  it("should return the current timestamp in milliseconds", () => {
    const timestamp = getTimestamp();
    expect(typeof timestamp).toBe("number");
    expect(timestamp).toBeCloseTo(Date.now(), -2);
  });
  it("should return the current timestamp in seconds", () => {
    const timestampInSeconds = getTimestampInSeconds();
    expect(typeof timestampInSeconds).toBe("number");
    expect(timestampInSeconds).toBeCloseTo(Math.floor(Date.now() / 1e3), -2);
  });
  it("should convert seconds to a Date object", () => {
    const seconds = 1640995200;
    const date = dateFromSeconds(seconds);
    expect(date).toEqual(/* @__PURE__ */ new Date("2022-01-01T00:00:00.000Z"));
  });
  it("should format milliseconds", () => {
    const milliseconds = 1234;
    const formatted = formatMilliseconds(milliseconds);
    expect(formatted).toBe("1.2 s");
  });
  it("should return the current timestamp using performance.now if available", () => {
    const timestamp = getPerformanceTimestamp();
    expect(typeof timestamp).toBe("number");
    expect(timestamp).toBeCloseTo(typeof performance !== "undefined" ? performance.now() : Date.now(), -2);
  });
  it("should measure the duration of a function", async () => {
    const getDuration = duration();
    await sleep(50);
    const elapsed = getDuration();
    expect(/\d+.\d\d ms/.test(elapsed)).toBe(true);
  });
  it("should convert a date to UTC time", () => {
    const date = /* @__PURE__ */ new Date("2022-01-01T12:00:00");
    const utcDate = datetimeToUTC(date);
    expect(utcDate).toEqual(/* @__PURE__ */ new Date("2022-01-01T12:00:00Z"));
  });
});
//# sourceMappingURL=time.spec.js.map